==> jhub_scheduler-0.1.2.tgz: package/lib/BrowseFileDialog.js <==
/*
 * Copyright 2018-2020 IBM Corporation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
// import { Dialog } from '@jupyterlab/apputils';
import { Dialog } from './dialog';
import { BreadCrumbs, DirListing, FilterFileBrowserModel } from '@jupyterlab/filebrowser';
import { Widget, PanelLayout } from '@lumino/widgets';
const BROWSE_FILE_CLASS = 'elyra-browseFileDialog';
const BROWSE_FILE_OPEN_CLASS = 'elyra-browseFileDialog-open';
/**
 * Breadcrumbs widget for browse file dialog body.
 */
export class BrowseFileDialogBreadcrumbs extends BreadCrumbs {
    constructor(options) {
        super(options);
        this.model = options.model;
        this.rootPath = options.rootPath;
    }
    onUpdateRequest(msg) {
        super.onUpdateRequest(msg);
        const contents = this.model.manager.services.contents;
        const localPath = contents.localPath(this.model.path);
        // if 'rootPath' is defined prevent navigating to it's parent/grandparent directories
        if (localPath && this.rootPath && localPath.indexOf(this.rootPath) === 0) {
            const breadcrumbs = document.querySelectorAll('.elyra-browseFileDialog .jp-BreadCrumbs > span[title]');
            breadcrumbs.forEach((crumb) => {
                if (crumb.title.indexOf(this.rootPath) === 0) {
                    crumb.className = crumb.className
                        .replace('elyra-BreadCrumbs-disabled', '')
                        .trim();
                }
                else if (crumb.className.indexOf('elyra-BreadCrumbs-disabled') === -1) {
                    crumb.className += ' elyra-BreadCrumbs-disabled';
                }
            });
        }
    }
}
/**
 * Browse file widget for dialog body
 */
export class BrowseFileDialog extends Widget {
    constructor(props) {
        super(props);
        this.model = new FilterFileBrowserModel({
            manager: props.manager,
            filter: props.filter
        });
        const layout = (this.layout = new PanelLayout());
        this.directoryListing = new DirListing({
            model: this.model
        });
        this.acceptFileOnDblClick = props.acceptFileOnDblClick;
        this.multiselect = props.multiselect;
        this.includeDir = props.includeDir;
        this.dirListingHandleEvent = this.directoryListing.handleEvent;
        this.directoryListing.handleEvent = (event) => {
            this.handleEvent(event);
        };
        this.breadCrumbs = new BrowseFileDialogBreadcrumbs({
            model: this.model,
            rootPath: props.rootPath
        });
        layout.addWidget(this.breadCrumbs);
        layout.addWidget(this.directoryListing);
        console.log('get into BrowseFileDialog _init');
    }
    static async init(options) {
        console.log('get into BrowseFileDialog init');
        const browseFileDialog = new BrowseFileDialog(options);
        console.log('get into BrowseFileDialog init options.startPath: ' + options.startPath);
        if (options.startPath) {
            if (!options.rootPath ||
                options.startPath.indexOf(options.rootPath) === 0) {
                console.log('get into BrowseFileDialog init await browseFileDialog.model.cd(options.startPath);' + options.startPath);
                await browseFileDialog.model.cd(options.startPath);
            }
        }
        else if (options.rootPath) {
            console.log('get into BrowseFileDialog init options.rootPath: ' + options.rootPath);
            await browseFileDialog.model.cd(options.rootPath);
        }
        return browseFileDialog;
    }
    getValue() {
        const itemsIter = this.directoryListing.selectedItems();
        const selected = [];
        let item = null;
        while ((item = itemsIter.next()) !== undefined) {
            if (this.includeDir || item.type !== 'directory') {
                selected.push(item);
            }
        }
        return selected;
    }
    handleEvent(event) {
        let modifierKey = false;
        if (event instanceof MouseEvent) {
            modifierKey =
                event.shiftKey || event.metaKey;
        }
        else if (event instanceof KeyboardEvent) {
            modifierKey =
                event.shiftKey || event.metaKey;
        }
        switch (event.type) {
            case 'keydown':
            case 'keyup':
            case 'mousedown':
            case 'mouseup':
            case 'click':
                if (this.multiselect || !modifierKey) {
                    this.dirListingHandleEvent.call(this.directoryListing, event);
                }
                break;
            case 'dblclick': {
                const clickedItem = this.directoryListing.modelForClick(event);
                if (clickedItem.type === 'directory') {
                    this.dirListingHandleEvent.call(this.directoryListing, event);
                }
                else {
                    event.preventDefault();
                    event.stopPropagation();
                    if (this.acceptFileOnDblClick) {
                        const okButton = document.querySelector(`.${BROWSE_FILE_OPEN_CLASS} .jp-mod-accept`);
                        if (okButton) {
                            okButton.click();
                        }
                    }
                }
                break;
            }
            default:
                this.dirListingHandleEvent.call(this.directoryListing, event);
                break;
        }
    }
}
export const showBrowseFileDialog = async (manager, options) => {
    console.log('get into func showBrowseFileDialog');
    const browseFileDialogBody = await BrowseFileDialog.init({
        manager: manager,
        filter: options.filter,
        multiselect: options.multiselect,
        includeDir: options.includeDir,
        rootPath: options.rootPath,
        startPath: options.startPath,
        acceptFileOnDblClick: Object.prototype.hasOwnProperty.call(options, 'acceptFileOnDblClick')
            ? options.acceptFileOnDblClick
            : true
    });
    const dialog = new Dialog({
        title: 'Select a file',
        body: browseFileDialogBody,
        buttons: [Dialog.cancelButton(), Dialog.okButton({ label: 'Select' })],
        host: document.body
        // host: document.body.getElementsByTagName('table')[0]
    });
    dialog.addClass(BROWSE_FILE_CLASS);
    // document.body.getElementsByTagName('table')[0].className += ` ${BROWSE_FILE_OPEN_CLASS}`;
    document.body.className += ` ${BROWSE_FILE_OPEN_CLASS}`;
    return dialog.launch().then((result) => {
        console.log('get into dialog.launch().then()');
        document.body.className = document.body.className
            .replace(BROWSE_FILE_OPEN_CLASS, '')
            .trim();
        // document.body.getElementsByTagName('table')[0].className = document.body.className
        //     .replace(BROWSE_FILE_OPEN_CLASS, '')
        //     .trim();
        if (options.rootPath && result.button.accept && result.value.length) {
            const relativeToPath = options.rootPath.endsWith('/')
                ? options.rootPath
                : options.rootPath + '/';
            result.value.forEach((val) => {
                val.path = val.path.replace(relativeToPath, '');
            });
        }
        console.log('get into dialog.launch().then(): ' + result);
        return result;
    });
};
export default showBrowseFileDialog;

==> jhub_scheduler-0.1.7.tgz: package/lib/BrowseFileDialog.js <==
/*
 * Copyright 2018-2020 IBM Corporation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
// import { Dialog } from '@jupyterlab/apputils';
import { Dialog } from './dialog';
import { BreadCrumbs, DirListing, FilterFileBrowserModel } from '@jupyterlab/filebrowser';
import { Widget, PanelLayout } from '@lumino/widgets';
const BROWSE_FILE_CLASS = 'elyra-browseFileDialog';
const BROWSE_FILE_OPEN_CLASS = 'elyra-browseFileDialog-open';
/**
 * Breadcrumbs widget for browse file dialog body.
 */
export class BrowseFileDialogBreadcrumbs extends BreadCrumbs {
    constructor(options) {
        super(options);
        this.model = options.model;
        this.rootPath = options.rootPath;
    }
    onUpdateRequest(msg) {
        super.onUpdateRequest(msg);
        const contents = this.model.manager.services.contents;
        const localPath = contents.localPath(this.model.path);
        // if 'rootPath' is defined prevent navigating to it's parent/grandparent directories
        if (localPath && this.rootPath && localPath.indexOf(this.rootPath) === 0) {
            const breadcrumbs = document.querySelectorAll('.elyra-browseFileDialog .jp-BreadCrumbs > span[title]');
            breadcrumbs.forEach((crumb) => {
                if (crumb.title.indexOf(this.rootPath) === 0) {
                    crumb.className = crumb.className
                        .replace('elyra-BreadCrumbs-disabled', '')
                        .trim();
                }
                else if (crumb.className.indexOf('elyra-BreadCrumbs-disabled') === -1) {
                    crumb.className += ' elyra-BreadCrumbs-disabled';
                }
            });
        }
    }
}
/**
 * Browse file widget for dialog body
 */
export class BrowseFileDialog extends Widget {
    constructor(props) {
        super(props);
        this.model = new FilterFileBrowserModel({
            manager: props.manager,
            filter: props.filter
        });
        const layout = (this.layout = new PanelLayout());
        this.directoryListing = new DirListing({
            model: this.model
        });
        this.acceptFileOnDblClick = props.acceptFileOnDblClick;
        this.multiselect = props.multiselect;
        this.includeDir = props.includeDir;
        this.dirListingHandleEvent = this.directoryListing.handleEvent;
        this.directoryListing.handleEvent = (event) => {
            this.handleEvent(event);
        };
        this.breadCrumbs = new BrowseFileDialogBreadcrumbs({
            model: this.model,
            rootPath: props.rootPath
        });
        layout.addWidget(this.breadCrumbs);
        layout.addWidget(this.directoryListing);
        console.log('get into BrowseFileDialog _init');
    }
    static async init(options) {
        console.log('get into BrowseFileDialog init');
        const browseFileDialog = new BrowseFileDialog(options);
        console.log('get into BrowseFileDialog init options.startPath: ' + options.startPath);
        if (options.startPath) {
            if (!options.rootPath ||
                options.startPath.indexOf(options.rootPath) === 0) {
                console.log('get into BrowseFileDialog init await browseFileDialog.model.cd(options.startPath);' + options.startPath);
                await browseFileDialog.model.cd(options.startPath);
            }
        }
        else if (options.rootPath) {
            console.log('get into BrowseFileDialog init options.rootPath: ' + options.rootPath);
            await browseFileDialog.model.cd(options.rootPath);
        }
        return browseFileDialog;
    }
    getValue() {
        const itemsIter = this.directoryListing.selectedItems();
        const selected = [];
        let item = null;
        while ((item = itemsIter.next()) !== undefined) {
            if (this.includeDir || item.type !== 'directory') {
                selected.push(item);
            }
        }
        return selected;
    }
    handleEvent(event) {
        let modifierKey = false;
        if (event instanceof MouseEvent) {
            modifierKey =
                event.shiftKey || event.metaKey;
        }
        else if (event instanceof KeyboardEvent) {
            modifierKey =
                event.shiftKey || event.metaKey;
        }
        switch (event.type) {
            case 'keydown':
            case 'keyup':
            case 'mousedown':
            case 'mouseup':
            case 'click':
                if (this.multiselect || !modifierKey) {
                    this.dirListingHandleEvent.call(this.directoryListing, event);
                }
                break;
            case 'dblclick': {
                const clickedItem = this.directoryListing.modelForClick(event);
                if (clickedItem.type === 'directory') {
                    this.dirListingHandleEvent.call(this.directoryListing, event);
                }
                else {
                    event.preventDefault();
                    event.stopPropagation();
                    if (this.acceptFileOnDblClick) {
                        const okButton = document.querySelector(`.${BROWSE_FILE_OPEN_CLASS} .jp-mod-accept`);
                        if (okButton) {
                            okButton.click();
                        }
                    }
                }
                break;
            }
            default:
                this.dirListingHandleEvent.call(this.directoryListing, event);
                break;
        }
    }
}
export const showBrowseFileDialog = async (manager, options) => {
    console.log('get into func showBrowseFileDialog');
    const browseFileDialogBody = await BrowseFileDialog.init({
        manager: manager,
        filter: options.filter,
        multiselect: options.multiselect,
        includeDir: options.includeDir,
        rootPath: options.rootPath,
        startPath: options.startPath,
        acceptFileOnDblClick: Object.prototype.hasOwnProperty.call(options, 'acceptFileOnDblClick')
            ? options.acceptFileOnDblClick
            : true
    });
    const dialog = new Dialog({
        title: 'Select a file',
        body: browseFileDialogBody,
        buttons: [Dialog.cancelButton(), Dialog.okButton({ label: 'Select' })],
        host: document.body
        // host: document.body.getElementsByTagName('table')[0]
    });
    dialog.addClass(BROWSE_FILE_CLASS);
    // document.body.getElementsByTagName('table')[0].className += ` ${BROWSE_FILE_OPEN_CLASS}`;
    document.body.className += ` ${BROWSE_FILE_OPEN_CLASS}`;
    return dialog.launch().then((result) => {
        console.log('get into dialog.launch().then()');
        document.body.className = document.body.className
            .replace(BROWSE_FILE_OPEN_CLASS, '')
            .trim();
        // document.body.getElementsByTagName('table')[0].className = document.body.className
        //     .replace(BROWSE_FILE_OPEN_CLASS, '')
        //     .trim();
        // if (options.rootPath && result.button.accept && result.value.length) {
        //     const relativeToPath = options.rootPath.endsWith('/')
        //         ? options.rootPath
        //         : options.rootPath + '/';
        //     result.value.forEach((val: any) => {
        //         val.path = val.path.replace(relativeToPath, '');
        //     });
        // }
        console.log('get into dialog.launch().then(): ' + result);
        return result;
    });
};
export default showBrowseFileDialog;
